<?php
/**
* @version $Id:	mycheckboxes.php $
* @version		3.1.0 28/11/2019
* @package		com_myjspace
* @author		Bernard Saulmé
* @copyright	Copyright (C) 2012 - 2019 Bernard Saulmé, based on Joomla! checkboxes.php
* @license		GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;

class JFormFieldMycheckboxes extends JFormField
{
	/**
	 * The form field type.
	 */
	protected $type = 'Mycheckboxes';

	/**
	 * Flag to tell the field to always be in multiple values mode.
	 *
	 * @var	boolean
	 */
	protected $forceMultiple = true;

	/**
	 * Method to get the field input markup for check boxes.
	 *
	 * @return  string  The field input markup.
	 */
	protected function getInput()
	{
		// Initialize variables
		$html = array();

		// Default
		if (is_string($this->value) && ($this->value)) {
			$this->value = explode(',', (string)$this->element['default']);
		}

		// Initialize some field attributes
		$class = $this->element['class'] ? ' class="checkboxes '.(string)$this->element['class'].'"' : ' class="checkboxes"';

		// Start the checkbox field output
		$html[] = '<fieldset id="'.$this->id.'"'.$class.'>';

		// Get the field options
		$options = $this->getOptions();

		// Build the checkbox field output
		$html[] = '<ul>';
		foreach ($options as $i => $option) {
			// Initialize some option attributes
			$checked = (in_array((string) $option->value, (array) $this->value) ? ' checked="checked"' : '');
			$class = !empty($option->class) ? ' class="'.$option->class.'"' : '';
			$disabled = !empty($option->disable) ? ' disabled="disabled"' : '';

			// Initialize some JavaScript option attributes
			$onclick = !empty($option->onclick) ? ' onclick="'.$option->onclick.'"' : '';

			$html[] = '<li>';
			$html[] = '<input type="checkbox" id="'.$this->id.$i.'" name="'.$this->name.'"'.' value="'
				.htmlspecialchars($option->value, ENT_COMPAT, 'UTF-8').'"'.$checked.$class.$onclick.$disabled.'/>';

			$html[] = '<label for="'.$this->id.$i.'"'.$class.'>'.JText::_($option->text).'</label>';
			$html[] = '</li>';
		}
		$html[] = '</ul>';

		// End the checkbox field output
		$html[] = '</fieldset>';

		return implode($html);
	}

	/**
	 * Method to get the field options.
	 *
	 * @return  array  The field option objects.
	 */
	protected function getOptions()
	{
		// Initialize variables
		$options = array();

		foreach ($this->element->children() as $option) {

			// Only add <option /> elements
			if ($option->getName() != 'option') {
				continue;
			}

			// Create a new option object based on the <option /> element
			$tmp = JHtml::_(
				'select.option', (string) $option['value'], trim((string) $option), 'value', 'text',
				((string) $option['disabled'] == 'true')
			);

			// Set some option attributes
			$tmp->class = (string) $option['class'];

			// Set some JavaScript option attributes
			$tmp->onclick = (string) $option['onclick'];

			// Add the option object to the result set
			$options[] = $tmp;
		}

		reset($options);

		return $options;
	}
}
