<?php
/**
* @version $Id: install.php $
* @version		3.1.0 01/11/2019
* @package		plg_pagebreakmyjspace
* @author       Bernard Saulm
* @copyright	Copyright (C) 2011 - 2019 Bernard Saulm
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;

/*
 * Enable, the plugin after install >= J!1.6
 */

class plgContentpagebreakmyjspaceInstallerScript
{
	protected $minimumPHPVersion = '5.3.1';
	protected $minimumJoomlaVersion = '3.4.0';
	protected $componentName = 'pagebreakmyjspace';

	/**
	 * Joomla! pre-flight event. This runs before Joomla! installs or updates the package. This is our last chance to
	 * tell Joomla! if it should abort the installation.
	 *
	 * @param   string                     $type    Installation type (install, update, discover_install)
	 * @param   \JInstallerAdapterPackage  $parent  Parent object
	 *
	 * @return  boolean  True to let the installation proceed, false to halt the installation
	 */
	public function preflight($type, $parent)
	{
		if (version_compare(JVERSION, $this->minimumJoomlaVersion, 'lt')) { // Check Joomla! version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least Joomla! '.$this->minimumJoomlaVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}

		if (version_compare(PHP_VERSION, $this->minimumPHPVersion, 'lt')) { // Check PHP version for component compatibility
			JFactory::getApplication()->enqueueMessage('You need at least PHP '.$this->minimumPHPVersion.' to install this '.$this->componentName.' version', 'error');
			return false;
		}

		return true;
	}

	/**
	 * Runs after install, update or discover_update. In other words, it executes after Joomla! has finished installing
	 * or updating your component. This is the last chance you've got to perform any additional installations, clean-up,
	 * database updates and similar housekeeping functions.
	 *
	 * @param   string                       $type   install, uninstall, update or discover_update
	 * @param   \JInstallerAdapterComponent  $parent Parent object
	 *
	 * @return  boolean
	 */
	function postflight($type, $parent)
	{
		// Get this plugin group, element
		$group = 'content';
		$element = 'pagebreakmyjspace';

		if ($type == 'install') { // Enable plugin
			$this->enablePlugin($group, $element);
		}

		return true;
	}

	/**
	 * Enable plugin
	 *
	 * @param   string  $group
	 * @param   string  $element
	 *
	 * @return  boolean
	 */
	function enablePlugin($group, $element)
	{
		$plugin = JTable::getInstance('extension');

		if (!$plugin->load(array('type'=>'plugin', 'folder'=>$group, 'element'=>$element))) {
			return false;
		}
		$plugin->enabled = 1;

		return $plugin->store();
	}
}
