<?php
/**
* @version $Id: myspacesearch.php $
* @version		3.1.0 11/10/2019
* @package		plg_search_myjspace
* @author       Bernard Saulmé
* @copyright	Copyright (C) 2010 - 2019 Bernard Saulmé
* @license      GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
*/

defined('_JEXEC') or die;

class plgSearchMyjspacesearch extends JPlugin
{
	protected $autoloadLanguage = true;
	protected $extension = 'com_myjspace';

	// Function to return an array of search areas.
	function onContentSearchAreas()
	{
		static $areas = array();

		// BS Myjspace component ACL
		if ($this->params->get('use_com_acl', 0) && !JFactory::getUser()->authorise('user.search', 'com_myjspace'))
			return array();

		if (empty($areas))
			$areas['myjspace'] = JText::_('PLG_MYJSPACESEARCH_PAGE');

		return $areas;
	}

	// Search function
	function onContentSearch($text, $phrase = '', $ordering = '', $areas = null)
	{
		$db = JFactory::getDBO();
		$user_actual = JFactory::getuser();
		$pparams = JComponentHelper::getParams('com_myjspace');
		$nullDate = $db->getNullDate();

		// BS MyJspace component not installed
		if (JComponentHelper::isEnabled($this->extension) === false)
			return array();

		// BS Myjspace component ACL
		if ($this->params->get('use_com_acl', 1) && !JFactory::getUser()->authorise('user.search', 'com_myjspace'))
			return array();

		require_once JPATH_ROOT.'/components/com_myjspace/helpers/util.php';

		// If the array is not correct, return it:
		if (is_array($areas) && !array_intersect($areas, array_keys($this->onContentSearchAreas())))
			return array();

		// Define the parameters
		$limit = $this->params->get('search_limit', 50);
		// URL display mode
		$param_url_mode = $this->params->get('param_url_mode', 0);
		$language_filter = $pparams->get('language_filter', 0); // Filter by language
		// ACL
		$search_restrict_acl = $this->params->get('search_restrict_acl', 0); // Restrict list with ACL

		if ($language_filter > 0) { // Filter by language
			$lang = JFactory::getLanguage();
			$language = $lang->getTag();
		} else {
			$language = '';
		}

		// Cleaning searching terms
		$text = trim($text);

		// Return empty array when nothing was filled in
		if ($text == '')
			return array();

		// Search for direct characters or for html equivalent for text with accent
		if ($this->params->get('search_html', 1))
			$text = htmlentities($text, ENT_QUOTES, 'UTF-8');

		// Search
		switch ($phrase) {
			// Search exact
			case 'exact' :
				$text = $db->q('%'.$db->escape($text, true).'%', false);
				$wheres2 = array();
				$wheres2 [] = $db->qn('title').' LIKE ' . $text . ' OR '.$db->qn('content').' LIKE ' . $text;
				$where = '(' . implode(') OR (', $wheres2) . ')';
				break;

			// Search all or any
			case 'all' :
			case 'any' :

			// Set default
			default :
				$words = explode(' ', $text);
				$wheres = array();
				foreach ($words as $word) {
					$word = $db->q('%'.$db->escape($word, true).'%', false);
					$wheres2 = array();
					$wheres2 [] = $db->qn('title').' LIKE ' . $word . ' OR '.$db->qn('content').' LIKE ' . $word;
					$wheres [] = implode(' OR ', $wheres2);
				}
				$where = '(' . implode(($phrase == 'all' ? ') AND (' : ') OR ('), $wheres) . ')';
				break;
		}

		if ($language)
			$where .= ' AND '.$db->qn('language').' IN ('.$db->qn('*').','.$db->q($language).')';

		if ($search_restrict_acl > 0) { // Only pages from my ACL and my pages
			$user_actual = JFactory::getuser();
			if ($user_actual->id == 0)
				$where .= ' AND '.$db->qn('blockview').' IN ('.implode(',', $user_actual->getAuthorisedViewLevels()).')';
			else
				$where .= ' AND ('.$db->qn('blockview').' IN ('.implode(',', $user_actual->getAuthorisedViewLevels()).') OR '.$db->qn('userid').' = '.$user_actual->id.')';
		}

		// Ordering of the results
		switch ($ordering) {
			// Oldest first
			case 'oldest' :
				$order = $db->qn('create_date').' ASC';
				break;

			// Popular first
			case 'popular' :
				$order = $db->qn('hits').' ASC, '.$db->qn('create_date').' DESC';
				break;

			// Newest first
			case 'newest' :
				$order = $db->qn('create_date').' DESC';
				break;

			// Category order
			case 'category' :
				$order = $db->qn('catid').' ASC';
				break;

			// Alphabetic, ascending
			case 'alpha' :
			// Default setting: hit, create_date descending
			default :
				$order = $db->qn('hits').' ASC, '.$db->qn('create_date').' DESC';
		}

		$query = 'SELECT '.$db->qn('title').', '.$db->qn('pagename').', '.$db->qn('foldername').', '.$db->qn('userid').', '.$db->qn('content').' AS text, '.$db->qn('create_date').' AS created, '.$db->qn('blockview').', '.$db->qn('catid');
		$query .= ' FROM '.$db->qn('#__myjspace').' WHERE '.$db->qn('blockview').' != 0 AND '.$db->qn('content')." != ''";
		$query .= '	AND	'.$db->qn('publish_up').' < NOW() AND ('.$db->qn('publish_down').' >= NOW() OR '.$db->qn('publish_down').' = '.$db->q($nullDate).')';
		$query .= ' AND '.$where.' ORDER BY '.$order;

		// Query
		$db->setQuery($query, 0, $limit);
		$rows = $db->loadObjectList();

		// Post processing !

		// If ACL filter for display this page
		$user_mode_view_acl = $pparams->get('user_mode_view_acl', 0);
		if ($user_mode_view_acl == 1)
			$access = $user_actual->getAuthorisedViewLevels();
		else
			$access = array();

		foreach ($rows as $key => $row) {
			$rows[$key]->section = JText::_('PLG_MYJSPACESEARCH_PAGE');
			$rows[$key]->browsernav = '2';

			// Search for folder
			if ($param_url_mode == 1)
				$repertoire = $row->foldername.'/';
			else
				$repertoire = 'index.php?option=com_myjspace&view=see&pagename=';

			$rows[$key]->href = Jroute::_($repertoire.$row->pagename);

			$check_acl = ($row->blockview >= 2 && (($user_mode_view_acl == 0 && $user_actual->id <= 0) || ($user_mode_view_acl == 1 && !in_array($row->blockview, $access))));

			if ($check_acl && $user_actual->id != $rows[$key]->userid) {
				$rows[$key]->text = JText::_('PLG_MYJSPACESEARCH_PAGE_NOREACHABLE');
			} else {
				$rows[$key]->text = BS_Util::clean_html_text($row->text, 0, $user_actual->id);
			}
		}

		// Return the search results in an array
		return $rows;
	}
}
